==> wink-client-0.1-incubating-sources.jar: org/apache/wink/client/internal/handlers/ClientRequestImpl.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *  
 *   http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *  
 *******************************************************************************/

package org.apache.wink.client.internal.handlers;

import java.net.URI;

import org.apache.wink.client.ClientRequest;

public class ClientRequestImpl extends BaseRequestResponseImpl implements ClientRequest {

    public static final String RESPONSE_ENTITY_GENERIC_TYPE = "response.entity.generic.type";
    public static final String RESPONSE_ENTITY_CLASS_TYPE   = "response.entity.class.type";

    private Object             entity;
    private String             method;
    private URI                uri;

    public Object getEntity() {
        return entity;
    }

    public String getMethod() {
        return method;
    }

    public URI getURI() {
        return uri;
    }

    public void setEntity(Object entity) {
        this.entity = entity;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public void setURI(URI uri) {
        this.uri = uri;
    }

}

==> wink-client-1.1-incubating-sources.jar: org/apache/wink/client/internal/handlers/ClientRequestImpl.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *  
 *   http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *  
 *******************************************************************************/

package org.apache.wink.client.internal.handlers;

import java.net.URI;

import org.apache.wink.client.ClientRequest;

public class ClientRequestImpl extends BaseRequestResponseImpl implements ClientRequest {

    public static final String RESPONSE_ENTITY_GENERIC_TYPE = "response.entity.generic.type"; //$NON-NLS-1$
    public static final String RESPONSE_ENTITY_CLASS_TYPE   = "response.entity.class.type"; //$NON-NLS-1$

    private Object             entity;
    private String             method;
    private URI                uri;

    public Object getEntity() {
        return entity;
    }

    public String getMethod() {
        return method;
    }

    public URI getURI() {
        return uri;
    }

    public void setEntity(Object entity) {
        this.entity = entity;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public void setURI(URI uri) {
        this.uri = uri;
    }

}
